@@ -31,6 +31,7 @@ from ._jsii import *
         "template_file": "templateFile",
         "parameters": "parameters",
         "stack_name": "stackName",
+        "tags": "tags",
     },
 )
 class AliyunRosStackProperties:
@@ -40,12 +41,14 @@ class AliyunRosStackProperties:
         template_file: builtins.str,
         parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         stack_name: typing.Optional[builtins.str] = None,
+        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     ) -> None:
         '''Artifact properties for ROS stacks.
 
         :param template_file: A file relative to the assembly root which contains the ROS template for this stack.
         :param parameters: Values for ROS stack parameters that should be passed when the stack is deployed. Default: - No parameters
         :param stack_name: The name to use for the ROS stack. Default: - name derived from artifact ID
+        :param tags: Values for ROS stack tags that should be passed when the stack is deployed. Default: - No tags
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "template_file": template_file,
@@ -54,6 +57,8 @@ class AliyunRosStackProperties:
             self._values["parameters"] = parameters
         if stack_name is not None:
             self._values["stack_name"] = stack_name
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def template_file(self) -> builtins.str:
@@ -80,6 +85,15 @@ class AliyunRosStackProperties:
         result = self._values.get("stack_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        '''Values for ROS stack tags that should be passed when the stack is deployed.
+
+        :default: - No tags
+        '''
+        result = self._values.get("tags")
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
